@@ -175,6 +175,12 @@ fi
 
 case "$switch" in
    "start"|"restart")
+     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+     echo "$msg_this_is_for_drbl_server_not_for_clonezilla_server_edition"
+     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+     echo -n $msg_press_enter_to_continue
+     read
+
      # config network first:
      config_network
 
